{
  pkgs,
  inputs,
  ...
}:
let
  common = import ../common.nix;
  username = common.username;
  dir = common.dir;
in
{
  imports = [
    inputs.catppuccin.homeManagerModules.catppuccin
    ./btop.nix
    ./cava
    ./cursors.nix
    ./default-applications.nix
    ./development
    ./fastfetch.nix
    ./fish.nix
    ./freetube.nix
    ./gtk.nix
    ./kitty.nix
    ./mpv.nix
    ./nextcloud.nix
    ./rofi
    ./wlogout
    ./hyprland
    ./spicetify.nix # TODO env conflict on latest version
    ./yazi
    ./zen
  ];

  dconf = {
    enable = true;
    settings = {
      # Prefer dark mode for all GTK apps
      "org/gnome/desktop/interface".color-scheme = "prefer-dark";
    };
  };

  home = {
    username = username;
    homeDirectory = dir.home;

    sessionVariables = {
      XDG_PICTURES_DIR = dir.pictures; # Define the default dir for pictures
    };

    # You can update Home Manager without changing this value. See
    # the Home Manager release notes for a list of state version
    # changes in each release.
    stateVersion = common.system.version;
  };

  programs = {
    btop.enable = true;

    # Let Home Manager install and manage itself.
    home-manager.enable = true;
  };

  services = {
    gpg-agent = {
      enable = true;
      pinentryPackage = pkgs.pinentry-curses;
    };
  };
}
